#!/usr/bin/env python
import pytest
from pathlib import Path
from pylineseek import pylineseek

@pytest.fixture
def sample_file(tmp_path):
    """
    Create a temporary text file with three lines and a corresponding numlines.txt.
    """
    file_path = tmp_path / "test.txt"
    lines = ["first line\n", "second line\n", "third line\n"]
    file_path.write_text("".join(lines))
    
    # Create the numlines.txt file in the same directory since PyLineSeek expects it.
    numlines_file = file_path.parent / "numlines.txt"
    numlines_file.write_text(str(len(lines)))
    
    return file_path

def test_get_line(sample_file):
    """
    Test that PyLineSeek returns the expected lines.
    """
    # Use no compression and load the index into memory for simplicity.
    pl = pylineseek.PyLineSeek(sample_file, compress=False, header=False, load_index=True, use_mmap=False)
    assert pl.get_line(0).strip() == "first line"
    assert pl.get_line(1).strip() == "second line"
    assert pl.get_line(2).strip() == "third line"
    pl.close()

def test_random_line(sample_file):
    """
    Test the random-access consistency check.
    """
    pl = pylineseek.PyLineSeek(sample_file, compress=False, header=False, load_index=True, use_mmap=False)
    # This should run the internal test that compares the direct retrieval with sequential reading.
    pl.test_random_line(1)
    pl.close()
